@@ -216,6 +216,7 @@ class NXClient(Client):
         sample_interval=Client._NS_IN_S * 10,
         suppress_redundant=False,
         heartbeat_interval=None,
+        prefix=None,
     ):
         """A convenience wrapper of subscribe() which aids in building of SubscriptionRequest
         with request as subscribe SubscriptionList. This method accepts an iterable of simply xpath strings,
@@ -254,6 +255,8 @@ class NXClient(Client):
             Specifies the maximum allowable silent period in nanoseconds when
             suppress_redundant is in use. The target should send a value at least once
             in the period specified.
+        prefix: proto.Path, optional
+            Prefix path that can be used as a general path to prepend to all Path elements. (not supported on NX)
 
         Returns
         -------
@@ -294,6 +297,7 @@ class NXClient(Client):
             sample_interval,
             suppress_redundant,
             heartbeat_interval,
+            prefix,
         )
 
     @classmethod
